<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu_HU">
<context>
    <name>ComDialog</name>
    <message>
        <source>Qtel Error</source>
        <translation>Qtel hiba</translation>
    </message>
    <message>
        <source>Station data not found in directory server.
Can&apos;t create connection to</source>
        <translation>Az állomás adatai nem találhatóak a könyvtár-szerveren.
Nem tudom a kapcsolatot létrehozni</translation>
    </message>
    <message>
        <source>Could not create connection to remote host</source>
        <translation>Nem lehet kapcsolódni a távoli hoszthoz</translation>
    </message>
    <message>
        <source>INFO</source>
        <translation>INFO</translation>
    </message>
    <message>
        <source>Connected to </source>
        <translation>Kapcsolódva ehhez </translation>
    </message>
    <message>
        <source>Connecting to </source>
        <translation>Kapcsolódás ehhez </translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Kapcsolat bontva</translation>
    </message>
    <message>
        <source>Could not open mic audio device</source>
        <translation>Nem tudom megnyitni ezt az eszközt: mikrofon</translation>
    </message>
    <message>
        <source>Could not open speaker audio device</source>
        <translation>Nem tudom megnyitni ezt az eszközt: hangszóró</translation>
    </message>
    <message>
        <source>Could not create connection to</source>
        <translation>Nem tudok kapcsolatot létrehozni ehhez</translation>
    </message>
</context>
<context>
    <name>ComDialogBase</name>
    <message>
        <source>Communication Dialog</source>
        <translation>Kommunikációs párbeszéd</translation>
    </message>
    <message>
        <source>Station Information</source>
        <translation>Állomás információ</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Leírás:</translation>
    </message>
    <message>
        <source>?</source>
        <translation>?</translation>
    </message>
    <message>
        <source>IP-address:</source>
        <translation>IP cím:</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Név:</translation>
    </message>
    <message>
        <source>Time:</source>
        <translation>Idő:</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>Állapot:</translation>
    </message>
    <message>
        <source>Chat/Info</source>
        <translation>Chat/Info</translation>
    </message>
    <message>
        <source>RX</source>
        <translation>RX</translation>
    </message>
    <message>
        <source>TX</source>
        <translation>TX</translation>
    </message>
    <message>
        <source>&amp;Connect</source>
        <translation>&amp;Kapcsolódás</translation>
    </message>
    <message>
        <source>&amp;Disconnect</source>
        <translation>&amp;Bontás</translation>
    </message>
    <message>
        <source>Alt+D</source>
        <translation>ALT+D</translation>
    </message>
    <message>
        <source>VOX</source>
        <translation>VOX</translation>
    </message>
    <message>
        <source>VOX Enabled</source>
        <translation>VOX engedélyezve</translation>
    </message>
    <message>
        <source>Threshold:</source>
        <translation>Érzékenység:</translation>
    </message>
    <message>
        <source>Delay:</source>
        <translation>Késleltetés:</translation>
    </message>
    <message>
        <source>dB Level:</source>
        <translation>dB szint:</translation>
    </message>
    <message>
        <source>PTT</source>
        <translation>PTT</translation>
    </message>
</context>
<context>
    <name>EchoLinkDirectoryModel</name>
    <message>
        <source>Callsign</source>
        <translation>Hívójel</translation>
    </message>
    <message>
        <source>Location/Description</source>
        <translation>Hely/Leírás</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Állapot</translation>
    </message>
    <message>
        <source>Local Time</source>
        <translation>Helyi idő</translation>
    </message>
    <message>
        <source>Node ID</source>
        <translation>Csomópont-szám</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP cím</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Logging off from directory server...</source>
        <translation>Kijelentkezés a könyvtár szerverről...</translation>
    </message>
    <message>
        <source>Station list has been refreshed</source>
        <translation>Az állomáslista frissítve</translation>
    </message>
    <message>
        <source>Refreshing station list...</source>
        <translation>Állomáslista frissítése...</translation>
    </message>
    <message>
        <source>Qtel - Add station...</source>
        <translation>Qtel - Állomás hozzáadása...</translation>
    </message>
    <message>
        <source>Enter callsign of the station to add</source>
        <translation>Hozzáadott állomás hívójel bevitel</translation>
    </message>
    <message>
        <source>Qtel: Connect to IP</source>
        <translation>Qtel: Kapcsolódás IP-hez</translation>
    </message>
    <message>
        <source>Enter an IP address or hostname:</source>
        <translation>IP cím vagy hosztnév bevitele:</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation>Könyvjelzők</translation>
    </message>
    <message>
        <source>Links</source>
        <translation>Linkek</translation>
    </message>
    <message>
        <source>Repeaters</source>
        <translation>Átjátszók</translation>
    </message>
    <message>
        <source>Conferences</source>
        <translation>Konferenciák</translation>
    </message>
    <message>
        <source>Stations</source>
        <translation>Állomások</translation>
    </message>
    <message>
        <source>About Qtel</source>
        <translation>A Qtel programról</translation>
    </message>
    <message>
        <source>Qtel v</source>
        <translation>Qtel v</translation>
    </message>
    <message>
        <source> - Qt EchoLink client.
</source>
        <translation> - Qt Echolink kliens.</translation>
    </message>
    <message>
        <source>Copyright (C) 2011 Tobias Blomberg / SM0SVX

Qtel comes with ABSOLUTELY NO WARRANTY. This is free software, and you are welcome to redistribute it in accordance with the terms and conditions in the GNU GPL (General Public License) version 2 or later.</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>MainWindowBase</name>
    <message>
        <source>Qtel - the Qt EchoLink Client</source>
        <translation>Qtel - az-Echolink-Kliens</translation>
    </message>
    <message>
        <source>Conferences</source>
        <translation>Konferencia</translation>
    </message>
    <message>
        <source>Links</source>
        <translation>Linkek</translation>
    </message>
    <message>
        <source>Repeaters</source>
        <translation>Átjátszók</translation>
    </message>
    <message>
        <source>Stations</source>
        <translation>Állomások</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation>Kedvencek</translation>
    </message>
    <message>
        <source>Messages</source>
        <translation>Üzenetek</translation>
    </message>
    <message>
        <source>Accept</source>
        <translation>Elfogad</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Töröl</translation>
    </message>
    <message>
        <source>Callsign</source>
        <translation>Hívójel</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Név</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Idő</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Fájl</translation>
    </message>
    <message>
        <source>&amp;Directory</source>
        <translation>&amp;Könyvtár</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Segítség</translation>
    </message>
    <message>
        <source>About</source>
        <translation>A programról</translation>
    </message>
    <message>
        <source>&amp;About...</source>
        <translation>&amp;About...</translation>
    </message>
    <message>
        <source>About Qtel</source>
        <translation>A Qtel-ről</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Kilépés</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Kilépés</translation>
    </message>
    <message>
        <source>Quit the Qtel application</source>
        <translation>Kilépés-a-Qtel-programból</translation>
    </message>
    <message>
        <source>Qtel Settings...</source>
        <translation>Qtel Beállítások...</translation>
    </message>
    <message>
        <source>Open the Qtel settings dialog</source>
        <translation>Qtel beállítások megnyitása</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Frissítés</translation>
    </message>
    <message>
        <source>&amp;Refresh</source>
        <translation>F&amp;rissítés</translation>
    </message>
    <message>
        <source>Refresh station list</source>
        <translation>Állomáslista frissítése</translation>
    </message>
    <message>
        <source>Busy</source>
        <translation>Foglalt</translation>
    </message>
    <message>
        <source>&amp;Busy</source>
        <translation>&amp;Foglalt</translation>
    </message>
    <message>
        <source>View as busy</source>
        <translation>Foglaltnak-mutat</translation>
    </message>
    <message>
        <source>View as busy in directory server</source>
        <translation>Foglaltnak mutat a könyvtár szerveren</translation>
    </message>
    <message>
        <source>Connect to IP...</source>
        <translation>Kapcsolódás IP-hez...</translation>
    </message>
    <message>
        <source>Connect to selected...</source>
        <translation>Csatlakozás a kiválasztotthoz...</translation>
    </message>
    <message>
        <source>Incoming Connections</source>
        <translation>Bejövő kapcsolatok</translation>
    </message>
    <message>
        <source>&amp;Station</source>
        <translation>Á&amp;llomás</translation>
    </message>
    <message>
        <source>S&amp;ettings</source>
        <translation>&amp;Beállítások</translation>
    </message>
    <message>
        <source>Connect to &amp;selected...</source>
        <translation>Kapcsolódás a &amp;kiválasztott állomáshoz...</translation>
    </message>
    <message>
        <source>Connect to &amp;IP...</source>
        <translation>Kapcsolódás az &amp;IP címhez...</translation>
    </message>
    <message>
        <source>Qtel &amp;Settings...</source>
        <translation>Qtel &amp;beállítások...</translation>
    </message>
    <message>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <source>Add Selected To &amp;Bookmarks</source>
        <translation>Kijelölt állomás &amp;hozzáadása a könyvjelzőkhöz</translation>
    </message>
    <message>
        <source>Add the selected station in the station list to the bookmarks menu</source>
        <translation>A kijelölt állomás hozzáadása az állomáslistából a könyvjelző menühöz</translation>
    </message>
    <message>
        <source>Ctrl+U</source>
        <translation>Ctrl+U</translation>
    </message>
    <message>
        <source>&amp;Remove Selected From Bookmarks</source>
        <translation>Kiválasztott állomás &amp;eltávolítása a könyvjelzők közül</translation>
    </message>
    <message>
        <source>Remove the selected station from the bookmarks list</source>
        <translation>A kijelölt állomás eltávolítása a könyvjelzők listájáról</translation>
    </message>
    <message>
        <source>Add &amp;Named Station To Bookmarks</source>
        <translation>Az elnevezett állomás h&amp;ozzáadása a könyvjelzőkhöz</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>CTRL+Q</translation>
    </message>
    <message>
        <source>Connect to the selected station</source>
        <translation>Kapcsolódás a kijelölt állomáshoz</translation>
    </message>
    <message>
        <source>Connect to local station using IP address or hostname</source>
        <translation>Kapcsolódás helyi állomáshoz IP cím vagy hosztnév használatával</translation>
    </message>
    <message>
        <source>Immediately refresh the station list</source>
        <translation>Azonnal frissítem az állomáslistát</translation>
    </message>
    <message>
        <source>Add selected station to the bookmarks</source>
        <translation>Kijelölt állomás hozzáadása a könyvjelzőkhöz</translation>
    </message>
    <message>
        <source>Remove the selected station from the bookmarks</source>
        <translation>A kijelölt állomás eltávolítása a könyvjelzők listájáról</translation>
    </message>
    <message>
        <source>Add a station to the bookmarks by entering a callsign</source>
        <translation>Állomás hozzáadása a könyvjelzőkhöz a hívójel alapján</translation>
    </message>
    <message>
        <source>Show the about dialog</source>
        <translation>Információk a programról</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Qtel: Settings</source>
        <translation>Qtel: Beállítások</translation>
    </message>
    <message>
        <source>User Info</source>
        <translation>Felhasználó infó</translation>
    </message>
    <message>
        <source>User Information</source>
        <translation>Felhasználó-információ</translation>
    </message>
    <message>
        <source>Info
Message</source>
        <translation>Info üzenet</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Hely</translation>
    </message>
    <message>
        <source>Callsign</source>
        <translation>Hívójel</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Jelszó</translation>
    </message>
    <message>
        <source>Retype password</source>
        <translation>Jelszó újra</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Név</translation>
    </message>
    <message>
        <source>Directory Server Settings</source>
        <translation>Könyvtár szerver beállítása</translation>
    </message>
    <message>
        <source>Server</source>
        <translation>Szerver</translation>
    </message>
    <message>
        <source>Refresh time</source>
        <translation>Frissítési idő</translation>
    </message>
    <message>
        <source>min</source>
        <translation>perc</translation>
    </message>
    <message>
        <source>Time, in minutes, between station list refreshes</source>
        <translation>Az-idő-percekben-mielőtt-az-állomáslista-frissítésre-kerül</translation>
    </message>
    <message>
        <source>Register as busy on program startup</source>
        <translation>Regisztráljon-foglaltként-a-program-indulásakor</translation>
    </message>
    <message>
        <source>Start as busy</source>
        <translation>Indítás foglaltként</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Hang</translation>
    </message>
    <message>
        <source>Full duplex</source>
        <translation>Full duplex</translation>
    </message>
    <message>
        <source>Check this check box to enable full duplex operation</source>
        <translation>Jelöld-be-a-full-duplex-használathoz</translation>
    </message>
    <message>
        <source>Connect Sound</source>
        <translation>Kapcsolódás hang</translation>
    </message>
    <message>
        <source>The connect sound to use on incoming EchoLink connections</source>
        <translation>Bejövő-kapcsolódás-hangja-Echolink-kapcsolatnál</translation>
    </message>
    <message>
        <source>Browse...</source>
        <translation>Megnéz...</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Megszakít</translation>
    </message>
    <message>
        <source>Raw Sound Files (*.raw)</source>
        <translation>Raw hang-fájl (*.raw)</translation>
    </message>
    <message>
        <source>Choose a connect sound file</source>
        <translation>Válaszd-ki-a-kapcsolódási-hangot</translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation>Kínai</translation>
    </message>
    <message>
        <source>Japanese</source>
        <translation>Japán</translation>
    </message>
    <message>
        <source>Korean</source>
        <translation>Kóreai</translation>
    </message>
    <message>
        <source>Tamil</source>
        <translation>Tamil</translation>
    </message>
    <message>
        <source>Unicode, 8-bit</source>
        <translation>Unicode, 8-bit</translation>
    </message>
    <message>
        <source>Russian</source>
        <translation>Orosz</translation>
    </message>
    <message>
        <source>Ukrainian</source>
        <translation>Ukrán</translation>
    </message>
    <message>
        <source>Western</source>
        <translation>Nyugati</translation>
    </message>
    <message>
        <source>Central European</source>
        <translation>Közép Európai</translation>
    </message>
    <message>
        <source>Baltic</source>
        <translation>Balti</translation>
    </message>
    <message>
        <source>Cyrillic</source>
        <translation>Cirill</translation>
    </message>
    <message>
        <source>Arabic</source>
        <translation>Arab</translation>
    </message>
    <message>
        <source>Greek</source>
        <translation>Görög</translation>
    </message>
    <message>
        <source>Hebrew, visually ordered</source>
        <translation>Héber, vizuálisan elrendezett</translation>
    </message>
    <message>
        <source>Hebrew, logically ordered</source>
        <translation>Héber, logikailag elrendezett</translation>
    </message>
    <message>
        <source>Turkish</source>
        <translation>Török</translation>
    </message>
    <message>
        <source>Hebrew</source>
        <translation>Héber</translation>
    </message>
    <message>
        <source>Thai</source>
        <translation>Thai</translation>
    </message>
    <message>
        <source>Qtel: Password mismatch</source>
        <translation>Qtel: eltérő jelszó</translation>
    </message>
    <message>
        <source>Passwords do not match</source>
        <translation>A jelszó nem egyezik</translation>
    </message>
    <message>
        <source>Sound Settings</source>
        <translation>Hang beállítás</translation>
    </message>
    <message>
        <source>Mic audio device</source>
        <translation>Mikrofon</translation>
    </message>
    <message>
        <source>The audio device to use (e.g. alsa:default)</source>
        <translation>A hangeszköz használatban (pl.: alsa:default)</translation>
    </message>
    <message>
        <source>Speaker audio device</source>
        <translation>Hangszóró</translation>
    </message>
    <message>
        <source>QSO</source>
        <translation>QSO</translation>
    </message>
    <message>
        <source>QSO Dialog Settings</source>
        <translation>QSO párbeszéd beállítás</translation>
    </message>
    <message>
        <source>Chat encoding:</source>
        <translation>Cset kódolás:</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Hálózat</translation>
    </message>
    <message>
        <source>Servers</source>
        <translation>Szerverek</translation>
    </message>
    <message>
        <source>A space separated list of the hostname or IP address of the EchoLink directory servers to use</source>
        <translation>Egy szóközökkel elválasztott lista hosztnevek vagy IP címek, amiket az EchoLink könyvtár szerverek használnak</translation>
    </message>
    <message>
        <source>EchoLink Proxy Settings</source>
        <translation>Echolink proxy beállítások</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Engedélyez</translation>
    </message>
    <message>
        <source>If enabling EchoLink proxy you must supply a proxy server hostname or IP address.</source>
        <translation>Ha használni akarosz egy Echolink proxy szervert, add meg a hoszt nevét vagy IP címét.</translation>
    </message>
    <message>
        <source>The hostname or IP address of the EchoLink proxy server to use</source>
        <translation>Az Echolink proxy szerver hostneve vagy IP címe már használatban van</translation>
    </message>
    <message>
        <source>TCP Port</source>
        <translation>TCP port</translation>
    </message>
    <message>
        <source>The TCP port to connect to on the EchoLink proxy server, default 8100</source>
        <translation>A TCP port, amivel kapcsolódni tudsz az EchoLink proxy szerverhez alapértelmezetten 8100</translation>
    </message>
    <message>
        <source>The EchoLink PROXY password, not your normal EchoLink password. Leave empty for public proxy.</source>
        <translation>Az EchoLink PROXY jelszava nem az EchoLink bejelentkező jelszó. Hagyd üresen ha publikus proxihoz csatlakozol.</translation>
    </message>
    <message>
        <source>Sampling Rate</source>
        <translation>Mintavételi arány</translation>
    </message>
    <message>
        <source>EchoLink proxy configuration problem</source>
        <translation>EchoLink proxy beállítási hiba</translation>
    </message>
    <message>
        <source>EchoLink proxy enabled but no server given</source>
        <translation>EchoLink proxy engedélyezve de nincs szerver megadva</translation>
    </message>
    <message>
        <source>Bind address</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;A bind address can be specified to force Qtel to use a specific network interface if your computer has more than one. Specify the IP address of the interface to bind to.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>None</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
